@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 ##############################################################################
 #
 # Copyright (c) 2003 Zope Foundation and Contributors.
@@ -15,7 +15,7 @@
 """Extract message strings from python modules, page template files
 and ZCML files.
 
-$Id: extract.py 123970 2012-01-06 19:07:09Z mgedmin $
+$Id: extract.py 125861 2012-05-14 12:13:47Z icemac $
 """
 __docformat__ = 'restructuredtext'
 
@@ -97,7 +97,7 @@ class POTEntry(object):
     msgstr ""
     <BLANKLINE>
 
-    Unicode can be used in msgids and default values
+    Unicode can be used in msgids and default values:
 
     >>> entry = POTEntry(Message(u"\u263B", default=u"\u253A"))
     >>> entry.write(FakeFile())
@@ -106,6 +106,16 @@ class POTEntry(object):
     msgstr ""
     <BLANKLINE>
 
+    But msgid might be an ascii encoded string and `default` might be a
+    string with the DEFAULT_ENCODING, too:
+
+    >>> entry = POTEntry(Message("Oe", default="\xd6"))
+    >>> entry.write(FakeFile())
+    #. Default: "\326"
+    msgid "Oe"
+    msgstr ""
+    <BLANKLINE>
+
     """
 
     implements(IPOTEntry)
@@ -130,7 +140,9 @@ class POTEntry(object):
             file.write('#: %s:%s\n' % (filename, line))
         if (isinstance(self.msgid, Message) and
             self.msgid.default is not None):
-            default = self.msgid.default.strip().encode(DEFAULT_CHARSET)
+            default = self.msgid.default.strip()
+            if isinstance(default, unicode):
+                default = default.encode(DEFAULT_CHARSET)
             lines = normalize(default).split("\n")
             lines[0] = "#. Default: %s\n" % lines[0]
             for i in range(1, len(lines)):
